function [X1, X2, newState] = rnd_split_subsample(X, lastState)
% RND_SPLIT_SUBSAMPLE   Default subsampler for the stability index
% 
%   [X1, X2, newState] = RND_SPLIT_SUBSAMPLE(X, lastState) performs a
%   random "split" of the given dataset X into two equally sized (up to
%   one) datasets X1 and X2. It can therefore be used as a subsampling
%   scheme for the calculation of the stability index of a clustering
%   method.
%
%   The function doesn't maintain a state and therefore 
%   lastState = newState = [] always holds.
% 
%   See also STABILITY_INDEX.

%   Reference: Lange, Roth, Braun, and Buhmann, 
%   "Stability-Based Validation of Clustering Solutions",
%	Neural Computation, 16: 1299-1323, June, 2004, MIT Press
   
%   Original coding by Simon Meier
%   Copyright 2005 Swiss Federal Institute of Technology (ETH) Zurich
%   Institute for Computational Science
%   $Revision: 1.2 $ $Date: 2005/06/28 23:31:12 $


n = size(X,1);

P = randperm(n);

X1 = X(P(1:ceil(n/2)), :);
X2 = X(P(ceil(n/2)+1:n), :);

newState = [];
