function Y2 = stab_classifier(train, classify, X1, Y1, X2)
% STAB_CLASSIFIER   Create a classifier for the STABILITY_INDEX   
%
%   This is a wrapper to conveniently pack a training and a classification
%   routine for a specific classifier into a function satisfying the
%   requirements of the STABILITY_INDEX function. Use a function handle of
%   the form
% 
%       @(X1, Y1, X2)(stab_classifier(@train, @classify, X1, Y1, X2));
% 
%   The training function train must have the form:
% 
%       params = train(X1, Y1)
% 
%   where params are the parameters that where decided during the training
%   such that now the classification function classify can be called like:
% 
%       Y2 = classify(X2, params)
% 
%   which computes the labels Y2 of the data X2 if the classifier has the
%   paramters params.
% 
% 
%   See also STABILITY_INDEX, DEMO_STAB_1

% Original coding by Simon Meier
% Copyright 2005 Swiss Federal Institute of Technology (ETH) Zurich
% Institute for Computational Science
% $Revision: 1.2 $ $Date: 2005/06/28 23:31:12 $


params = train(X1, Y1);
Y2 = classify(X2, params);
