function C = train_nearest_centroid(X, Y)
% TRAIN_NEAREST_CENTROID    Trains a nearest centroid classifier
%
%   C = TRAIN_NEAREST_CENTROID(X, Y) returns a [k,m]-matrix with row-wise
%   entries for each centroid correspondig to a label type in Y 
%   where k = max(Y) - min(Y) + 1
%
%   See also CLASSIFY_NEAREST_CENTROID

%   Original coding by Simon Meier
%   Copyright 2005 Swiss Federal Institute of Technology (ETH) Zurich
%   Institute for Computational Science
%   $Revision: 1.2 $ $Date: 2005/06/28 23:31:11 $

%init
m = size(X,2);

ymin = min(Y);
ymax = max(Y);

% calc centroid of each class
% if a class has no members then its centroid is [inf,..,inf]
C = [];
for I = ymin:ymax
    indices = find(Y==I);
    if (isempty(indices))
        Xi = inf*ones(1,m);
    else
        Xi = X(indices, :);
    end
    C = [C; mean(Xi, 1)];
end;
